@@ -77,6 +77,8 @@ class MysqlHelper(Singleton):
             result = cursor.fetchall()
             cursor.close()
             conn.close()
+            if not result:
+                return []
             if len(result) > 0:
                 flag = False
                 for k, v in result[0].items():
@@ -100,6 +102,8 @@ class MysqlHelper(Singleton):
             result = cursor.fetchall()
             cursor.close()
             conn.close()
+            if not result:
+                return []
             if len(result) > 0:
                 flag = False
                 for k, v in result[0].items():
@@ -166,14 +170,11 @@ class MysqlHelper(Singleton):
         conn = None
         try:
             conn, cursor = self.createConn()
-            result = self.executeParam(cursor, sql, Param)
+            self.executeParam(cursor, sql, Param)
             conn.commit()
             cursor.close()
             conn.close()
-            if result > 0:
-                return True
-            else:
-                return False
+            return True
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
@@ -186,14 +187,11 @@ class MysqlHelper(Singleton):
                 raise Exception("Param must is list")
             else:
                 conn, cursor = self.createConn()
-                result = cursor.executemany(sql, Param)
+                cursor.executemany(sql, Param)
                 conn.commit()
                 cursor.close()
                 conn.close()
-                if result > 0:
-                    return True
-                else:
-                    return False
+                return True
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
@@ -229,6 +227,8 @@ class PgHelper(Singleton2):
             result = cursor.fetchall()
             cursor.close()
             conn.close()
+            if not result:
+                return []
             if len(result) > 0:
                 flag = False
                 for k, v in result[0].items():
@@ -252,6 +252,8 @@ class PgHelper(Singleton2):
             result = cursor.fetchall()
             cursor.close()
             conn.close()
+            if not result:
+                return []
             if len(result) > 0:
                 flag = False
                 for k, v in result[0].items():
@@ -320,14 +322,11 @@ class PgHelper(Singleton2):
         conn = None
         try:
             conn, cursor = self.createConn()
-            result = self.executeParam(cursor, sql, Param)
+            self.executeParam(cursor, sql, Param)
             conn.commit()
             cursor.close()
             conn.close()
-            if result > 0:
-                return True
-            else:
-                return False
+            return True
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
@@ -340,14 +339,11 @@ class PgHelper(Singleton2):
                 raise Exception("Param must is list")
             else:
                 conn, cursor = self.createConn()
-                result = cursor.executemany(sql, Param)
+                cursor.executemany(sql, Param)
                 conn.commit()
                 cursor.close()
                 conn.close()
-                if result > 0:
-                    return True
-                else:
-                    return False
+                return True
         except Exception as e:
             conn.rollback()
             self.Log.error(e)
